<template>
  <div>
  <el-card class="card-container">
    <div class="flex-container mb-4">
      <el-tabs v-model="currentTab" @tab-click="handleClick" v-show="isShow">
        <el-tab-pane
          v-for="item in TABS_DATA"
          :key="item.value"
          :label="item.label"
          :name="item.value"
        >
          <template slot-scope="item">
            <div class="tab-label">{{ item.label }}</div>
          </template>
        </el-tab-pane>
      </el-tabs>
    </div>
    <component
      :is="componentName"
      ref="childRef"
      :disabled="disabled"
      @toNext="changeTable"
      @updateIsShow="updateIsShow"
      @basicInfoForm="basicInfoForm"
      @investInfoForm="investInfoForm"
      @investmentFundsForm="investmentFundsForm"
      @legalPersonForm="legalPersonForm"
      @policyInfoForm="policyInfoForm"
      @documentsInfoForm="documentsInfoForm"
      :isShow="isShow"
      class="full-width custom-height"
    />
    <div v-if="audit" class="button-container">
      <el-button
        class="save-button"
        type="primary"
        @click="saveProject(2)"
      >通过</el-button>
      <el-button
        class="save-button"
        type="danger"
        @click="showDialog"
      >驳回</el-button>
    </div>

    <div v-if="!disabled" class="button-container">
      <el-button
        class="save-button"
        type="primary"
        @click="saveProject(0)"
        >草稿</el-button
      >
<!--      <el-button class="save-button" type="primary" @click="submit(1)"-->
<!--        >保存</el-button>-->
      <el-button class="save-button" type="primary" @click="saveProject(1)"
      >保存</el-button>
      <el-button class="reset-button" @click="reset">重置</el-button>
      <!-- <el-button v-else class="cancel-button" @click="cancel">取消</el-button> -->
    </div>
  </el-card>
    <el-dialog :visible.sync="remarkShow" width="1000px" title="驳回信息" append-to-body>
      <el-form ref="form" label-width="80px">
        <el-form-item label="驳回原因">
          <el-input type="textarea" v-model="remark"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancelAuditing">取 消</el-button>
        <el-button type="primary" @click="submitAuditing">确 定</el-button>
      </div>
    </el-dialog>
</div>
</template>

<script>
import BasicInfo from "@/views/projectEngineering/projectLibrary/component/BasicInfo";
import InvestInfo from "@/views/projectEngineering/projectLibrary/component/InvestInfo";
import InvestmentFunds from "@/views/projectEngineering/projectLibrary/component/investmentFunds";
import LegalPerson from "@/views/projectEngineering/projectLibrary/component/legalPerson";
import PolicyInfo from "@/views/projectEngineering/projectLibrary/component/PolicyInfo";
import DocumentsInfo from "@/views/projectEngineering/projectLibrary/component/DocumentsInfo";
import { editProject } from "@/api/projectEngineering/projectInfo";

export default {
  name: "ProjectDetails",
  data() {
    return {
      isShow: false,
      currentTab: "项目管理基础信息",
      disabled: false,
      remarkShow: false,
      audit: false,
      remark: '',
      projectForm: {},
      componentName: BasicInfo,
      projectId: null,
      TABS_DATA: [
        {
          label: "项目管理基础信息",
          value: "项目管理基础信息",
          componentName: BasicInfo,
        },
        // {
        //   label: "投资管理基础信息",
        //   value: "投资管理基础信息",
        //   componentName: InvestInfo,
        // },
        {
          label: "项目投资及资金来源",
          value: "项目投资及资金来源",
          componentName: InvestmentFunds,
        },
        {
          label: "项目(法人)单位登记信息",
          value: "项目(法人)单位登记信息",
          componentName: LegalPerson,
        },
        // {
        //   label: "投资项目产业政策符合情况",
        //   value: "投资项目产业政策符合情况",
        //   componentName: PolicyInfo,
        // },
        // {
        //   label: "相关文书",
        //   value: "相关文书",
        //   componentName: DocumentsInfo,
        // },
      ],
      childRef: null,
      rules: [
        {name: 'projectName', message: '请输入项目名称'},
        {name: 'content', message: '请输入建设内容'},
        {name: 'fundTypeList', message: '请选择资金类型'},
        {name: 'investType', message: '请选择项目投资类别'},
        {name: 'constructionNature', message: '请选择建设性质'},
        {name: 'attractInvestment', message: '请选择是否招商引资项目'},
        {name: 'projectType', message: '请选择项目推进类型'},
        {name: 'projectStatus', message: '请选择项目状态'},
        {name: 'projectPhase', message: '请选择项目阶段'},
        {name: 'projectContactPerson', message: '请输入项目联系人'},
        {name: 'contact', message: '请输入项目联系方式'},
        {name: 'projectOwnerUnit', message: '请选择项目业主单位'},
        {name: 'competentDepartment', message: '请选择主管部门'},
        {name: 'competentDepartmentPerson', message: '请选择主管部门联系人'},
        {name: 'competentDepartmentPhone', message: '请输入主管部门联系方式'},
        {name: 'area', message: '请选择行政区划'},
        {name: 'managementCentralizationList', message: '请选择管理归口'},
        {name: 'projectApprovalType', message: '请选择项目审批类型'},
        {name: 'importanceTypeList', message: '请选择重点分类'},
        {name: 'planStartTime', message: '请选择计划开工时间'},
        {name: 'planCompleteTime', message: '请选择计划竣工时间'},
        {name: 'industryCompetentDepartment', message: '请选择行业主管部门'},
        {name: 'industryCompetentDepartmentPerson', message: '请输入行业主管部门联系人'},
        {name: 'departmentPersonPhone', message: '请输入行业主管部门联系方式'},
    ]
    };
  },
  methods: {
    showDialog(){
      this.remark = null;
      this.remarkShow = true;
    },
    cancelAuditing(){
      this.remark = null;
      this.remarkShow = false;
    },
    submitAuditing(){
      this.projectForm.projectInfoForm.remark = this.remark
      this.saveProject(3)
      this.remark = null
      this.remarkShow = false;
    },
    updateIsShow(newValue) {
      this.isShow = newValue;
    },
    basicInfoForm(data) {
      this.projectForm.projectInfoForm = data;
      this.projectId = data.id;
      this.audit = this.$route.query.audit == 1 && this.projectForm.projectInfoForm.auditRole;
    },
    investInfoForm(data) {
      this.projectForm.projectInvestmentInfoForm = data;
      this.projectForm.projectInvestmentInfoForm.projectId = this.projectId;
    },
    investmentFundsForm(data) {
      this.projectForm.projectInvestmentFundingForm = data;
      this.projectForm.projectInvestmentFundingForm.projectId = this.projectId;
    },
    documentsInfoForm(data){
      this.projectForm.documentInfoForm = data;
      this.projectForm.documentInfoForm.projectId = this.projectId;
    },
    legalPersonForm(data) {
      this.projectForm.projectUnitRegistrationInfoForm = data;
      this.projectForm.projectUnitRegistrationInfoForm.projectId = this.projectId;
    },
    policyInfoForm(data) {
      this.projectForm.projectInvestmentPolicyComplianceForm = data;
      this.projectForm.projectInvestmentPolicyComplianceForm.projectId = this.projectId;
    },
    handleClick(tabTarget) {
      this.componentName = this.TABS_DATA[tabTarget.index].componentName;
    },
    changeTable(index) {
      this.componentName = this.TABS_DATA[index].componentName;
      this.currentTab = this.TABS_DATA[index].value;
    },
    submit(usedStatus) {
      this.$refs.childRef.submit(usedStatus);
    },
    reset() {
      this.$refs.childRef.reset();
    },
    saveProject(num) {
      this.projectForm.projectInfoForm.usedStatus = num;

      const msg = this.formValidate()
      if (msg && num != 0) {  // 草稿不校验
        this.$message.error(msg)
      } else {
        editProject(this.projectForm).then((res) => {
          this.$message.success("保存成功");
          this.$store.dispatch("tagsView/delView", this.$route);
          this.$router.push('/projectEngineering/project/projectLibrary')
        })
      }
    },
    /**
     * 临时使用这种方式校验
     */
    formValidate() {
      let msg = "";
      for (let i = 0; i < this.rules.length; i++) {
        console.log(this.projectForm)
        console.log(this.rules[i].name)
        console.log(this.projectForm.projectInfoForm[this.rules[i].name])
        if (! this.projectForm.projectInfoForm[this.rules[i].name]) {
          msg = this.rules[i].message
          break
        }
      }
      return msg;
    },
  },
  mounted() {
    if (this.$route.query.disabled) {
      this.disabled = true;
    }
  },
};
</script>

<style scoped>
::v-deep .el-tabs__nav-wrap::after {
  background-color: rgba(0, 0, 0, 0) !important;
}
.flex-container {
  display: flex;
  justify-content: space-between;
  margin-bottom: 16px;
}

.tab-label {
  font-size: 14px;
}

.full-width {
  width: 100%;
}

.custom-height {
  height: calc(100% - 55px);
}

.button-container {
  margin-top: 3%;
  margin-left: 3%;
  display: flex;
}

.save-button,
.reset-button {
  width: 72px;
}
</style>
